@@ -1,6 +1,6 @@
-#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
-(revision "A.00.00")
-(date "Thu 11/Apr/1991")
+#! /usr/lib/veetest/veetest -r
+(revision "A.00.01")
+(date "Wed 18/Sep/1991")
 (component 0 "Context"
  (name "Feedback5 Example")
  (interface
@@ -16,7 +16,7 @@
    )
    (views
     (icon
-     (origin 795 548)
+     (origin 795 678)
      (extent 110 25)
     )
     (detail
@@ -51,7 +51,7 @@
    )
    (views
     (icon
-     (origin 711 498)
+     (origin 711 628)
      (extent 78 25)
     )
     (detail
@@ -89,7 +89,7 @@
    )
    (views
     (icon
-     (origin 611 498)
+     (origin 611 628)
      (extent 78 25)
     )
     (detail
@@ -99,30 +99,7 @@
     (active icon)
    )
   )
-  (component 3 "TextDisplay"
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-    )
-    (detail
-     (origin 774 209)
-     (extent 173 223)
-    )
-    (active detail)
-   )
-  )
-  (component 4 "Gate"
+  (component 3 "Gate"
    (interface
     (sequence in)
     (sequence out)
@@ -142,7 +119,7 @@
    )
    (views
     (icon
-     (origin 307 288)
+     (origin 307 418)
      (extent 46 25)
     )
     (detail
@@ -151,7 +128,7 @@
     (active icon)
    )
   )
-  (component 5 "Formula"
+  (component 4 "Formula"
    (name "A+1")
    (interface
     (sequence in)
@@ -173,7 +150,7 @@
    )
    (views
     (icon
-     (origin 427 338)
+     (origin 427 468)
      (extent 46 25)
     )
     (detail
@@ -184,7 +161,7 @@
     (active icon)
    )
   )
-  (component 6 "ForCount"
+  (component 5 "ForCount"
    (interface
     (sequence in)
     (sequence out)
@@ -200,33 +177,16 @@
     (icon
      (origin 215 418)
      (extent 110 64)
-     (iconImage loop.icon)
+     (iconImage "loop.icon")
     )
     (detail
-     (origin 195 433)
+     (origin 195 563)
      (extent 170 34)
     )
     (active detail)
    )
   )
-  (component 7 "Start"
-   (interface
-    (sequence out)
-   )
-   (implementation
-   )
-   (views
-    (icon
-     (origin 67 92)
-     (extent 67 37)
-    )
-    (detail
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 8 "Constant"
+  (component 6 "Constant"
    (name "Integer")
    (interface
     (sequence in)
@@ -256,39 +216,517 @@
     (icon
     )
     (detail
-     (origin 25 201)
+     (origin 25 331)
      (extent 150 118)
      (showFormat int)
     )
     (active detail)
    )
   )
-  (component 9 "Note"
-   (name "Warranty Disclaimer")
+  (component 7 "IfThenElse"
+   (name "A[B+1]<A[B]")
    (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "A")
+     (optional yes)
+    )
+    (input 2
+     (type data)
+     (name "B")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name "Then")
+     (lock name constraints)
+    )
+    (output 2
+     (type data)
+     (name "Else")
+     (lock name constraints)
+    )
    )
    (implementation
-    (component text 5 5
-     This example is provided as an
-     illustration "as is", and 
-     Hewlett-PackardCompany makes no
-     warranty of any kind with regard
-      to this example.
+    (component isLocked no)
+    (component expr "A[B+1]<A[B]")
+   )
+   (views
+    (icon
+     (origin 454 358)
+     (extent 112 25)
+    )
+    (detail
+     (origin 324 198)
+     (extent 163 104)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 8 "Junction"
+   (name "JCT")
+   (interface
+    (input 1
+     (type data)
+     (name "A")
+     (lock name constraints)
+    )
+    (input 2
+     (type data)
+     (name "B")
+     (lock name constraints)
+    )
+    (input 3
+     (type data)
+     (name "C")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name "Data")
+     (lock name constraints)
+    )
+   )
+   (implementation
+   )
+   (views
+    (icon
+     (origin 227 343)
+     (extent 46 34)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 9 "RepeatUntilBreak"
+   (interface
+    (sequence in)
+    (sequence out)
+    (output 1
+     (type data)
+     (name "Continuous")
+     (lock name constraints)
+    )
+   )
+   (implementation
+   )
+   (views
+    (icon
+     (origin 45 478)
+     (extent 110 64)
+     (iconImage "loop.icon")
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 10 "Context"
+   (name "Swap(x,y)")
+   (description 9 4
+    This model inside the User Object is explained in
+    the /examples/concepts directory, It is used to
+    swap any two elements of an array. The array can
+    be any of the Vee data types. The inputs are the
+    array, two of whose elements are to be swapped. 
+    The other two inputs are the indices of the two 
+    elements. The indices should be attached in the 
+    correct order as indicated by the terminal names.
+    
+   )
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "ArrayIn")
+     (optional yes)
+    )
+    (input 2
+     (type data)
+     (name "Xindex")
+     (optional yes)
+    )
+    (input 3
+     (type data)
+     (name "Yindex")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name "SwappedArray")
+     (lock constraints)
+     (optional yes)
+    )
+   )
+   (implementation
+    (trigMode deg)
+    (locked no)
+    (component 0 "ToArray"
+     (interface
+      (sequence in)
+      (sequence out)
+      (input 1
+       (type data)
+       (name "Array")
+       (tag "Array")
+       (lock constraints)
+      )
+      (input 2
+       (type data)
+       (name "Datum")
+       (tag "Datum")
+       (requires
+        (shape "Scalar")
+       )
+       (lock constraints)
+      )
+      (input 3
+       (type data)
+       (name "Index 1")
+       (tag "Index 1")
+       (requires
+        (datatype Int32)
+        (shape "Scalar")
+       )
+       (lock constraints)
+      )
+      (input 4
+       (type trigger)
+       (name "XEQ")
+       (lock name constraints)
+      )
+      (output 1
+       (type data)
+       (name "Array")
+       (tag "Array")
+       (lock constraints)
+      )
+     )
+     (implementation
+      (component numDims 1)
+     )
+     (views
+      (icon
+       (origin 655 368)
+       (extent 110 64)
+       (iconImage "build.icon")
+      )
+      (detail
+      )
+      (terminals on)
+      (active icon)
+     )
+    )
+    (component 1 "Formula"
+     (interface
+      (sequence in)
+      (sequence out)
+      (input 1
+       (type data)
+       (name "A")
+       (optional yes)
+      )
+      (input 2
+       (type data)
+       (name "B")
+       (optional yes)
+      )
+      (output 1
+       (type data)
+       (name "Result")
+       (lock name constraints)
+      )
+     )
+     (implementation
+      (component isLocked no)
+      (component expr 1 "A[B]")
+     )
+     (views
+      (icon
+       (origin 341 358)
+       (extent 78 64)
+       (iconImage "formula.icon")
+      )
+      (detail
+       (origin 308 166)
+       (extent 74 108)
+      )
+      (terminals on)
+      (active icon)
+     )
+    )
+    (component 2 "Formula"
+     (interface
+      (sequence in)
+      (sequence out)
+      (input 1
+       (type data)
+       (name "A")
+       (optional yes)
+      )
+      (input 2
+       (type data)
+       (name "B")
+       (optional yes)
+      )
+      (output 1
+       (type data)
+       (name "Result")
+       (lock name constraints)
+      )
+     )
+     (implementation
+      (component isLocked no)
+      (component expr 1 "A[B]")
+     )
+     (views
+      (icon
+       (origin 341 178)
+       (extent 78 64)
+       (iconImage "formula.icon")
+      )
+      (detail
+       (origin 308 166)
+       (extent 74 108)
+      )
+      (terminals on)
+      (active icon)
+     )
+    )
+    (component 3 "ToArray"
+     (interface
+      (sequence in)
+      (sequence out)
+      (input 1
+       (type data)
+       (name "Array")
+       (tag "Array")
+       (lock constraints)
+      )
+      (input 2
+       (type data)
+       (name "Datum")
+       (tag "Datum")
+       (requires
+        (shape "Scalar")
+       )
+       (lock constraints)
+      )
+      (input 3
+       (type data)
+       (name "Index 1")
+       (tag "Index 1")
+       (requires
+        (datatype Int32)
+        (shape "Scalar")
+       )
+       (lock constraints)
+      )
+      (input 4
+       (type trigger)
+       (name "XEQ")
+       (lock name constraints)
+      )
+      (output 1
+       (type data)
+       (name "Array")
+       (tag "Array")
+       (lock constraints)
+      )
+     )
+     (implementation
+      (component numDims 1)
+     )
+     (views
+      (icon
+       (origin 495 148)
+       (extent 110 64)
+       (iconImage "build.icon")
+      )
+      (detail
+      )
+      (terminals on)
+      (active icon)
+     )
+    )
+    (configuration
+     (connect D3:1 D0:1)
+     (connect D1:1 D0:2)
+     (connect I2:1 D0:3)
+     (connect D3:0 D0:4)
+     (connect I1:1 D1:1)
+     (connect I3:1 D1:2)
+     (connect I1:1 D2:1)
+     (connect I2:1 D2:2)
+     (connect I1:1 D3:1)
+     (connect D2:1 D3:2)
+     (connect I3:1 D3:3)
+     (connect D2:0 D3:4)
+     (connect D0:1 O1:1)
     )
    )
    (views
     (icon
-     (extent 181 0)
+     (origin 620 428)
+     (extent 100 45)
     )
     (detail
-     (origin 12 579)
-     (extent 297 103)
-     (editing disabled)
+     (origin 175 117)
+     (extent 641 387)
+     (configuration
+      (connect D3:1 D0:1
+       (Point 607 180)
+       (Point 620 180)
+       (Point 620 380)
+       (Point 652 380)
+      )
+      (connect D1:1 D0:2
+       (Point 421 390)
+       (Point 652 390)
+      )
+      (connect I2:1 D0:3
+       (Point 177 320)
+       (Point 200 320)
+       (Point 200 440)
+       (Point 440 440)
+       (Point 440 400)
+       (Point 652 400)
+      )
+      (connect D3:0 D0:4
+       (Point 550 214)
+       (Point 550 410)
+       (Point 652 410)
+      )
+      (connect I1:1 D1:1
+       (Point 177 190)
+       (Point 310 190)
+       (Point 310 370)
+       (Point 338 370)
+      )
+      (connect I3:1 D1:2
+       (Point 177 450)
+       (Point 190 450)
+       (Point 190 410)
+       (Point 338 410)
+      )
+      (connect I1:1 D2:1
+       (Point 177 190)
+       (Point 338 190)
+      )
+      (connect I2:1 D2:2
+       (Point 177 320)
+       (Point 190 320)
+       (Point 190 230)
+       (Point 338 230)
+      )
+      (connect I1:1 D3:1
+       (Point 177 190)
+       (Point 310 190)
+       (Point 310 160)
+       (Point 492 160)
+      )
+      (connect D2:1 D3:2
+       (Point 421 210)
+       (Point 440 210)
+       (Point 440 170)
+       (Point 492 170)
+      )
+      (connect I3:1 D3:3
+       (Point 177 450)
+       (Point 190 450)
+       (Point 190 410)
+       (Point 320 410)
+       (Point 320 340)
+       (Point 460 340)
+       (Point 460 180)
+       (Point 492 180)
+      )
+      (connect D2:0 D3:4
+       (Point 380 244)
+       (Point 380 260)
+       (Point 450 260)
+       (Point 450 190)
+       (Point 492 190)
+      )
+      (connect D0:1 O1:1
+       (Point 767 400)
+       (Point 780 400)
+       (Point 780 320)
+       (Point 813 320)
+      )
+     )
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 11 "TextDisplay"
+   (name "AlphaNumeric")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+    )
+    (detail
+     (origin 794 351)
+     (extent 192 198)
     )
     (active detail)
    )
   )
-  (component 10 "Context"
+  (component 12 "SampleHold"
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "InData")
+     (tag "InData")
+     (lock constraints)
+    )
+    (input 2
+     (type trigger)
+     (name "XEQ")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "OutData")
+     (tag "OutData")
+     (lock constraints)
+    )
+   )
+   (implementation
+   )
+   (views
+    (icon
+     (origin 597 338)
+     (extent 127 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 13 "Context"
    (name "Press For")
    (interface
     (sequence in)
@@ -389,12 +827,16 @@
       (locked no)
       (component 0 "Note"
        (name "NotePad")
+       (description 2 8
+        This notepad is displayed as a Show on Execute
+        panel to present the information to the reader.
+       )
        (interface
        )
        (implementation
         (component text 45 9
-         PURPOSE: To show a more complex feedback loop involving actual constraints of objects
-                  within the feedback loop.
+         PURPOSE:     To show a more complex feedback loop involving actual constraints of objects
+                      within the feedback loop.
          
          USER INPUT REQUIRED: None
          
@@ -416,14 +858,14 @@
                       the array are done to achieve the correct order.  The object making the 
                       comparisons is an If/Then retitled to "A[B+1] < A[B]".  If this comparison
                       is true, i.e. the two adjacent elements are out of order, then the swap
-                      object is allowed to execute by the fact that the "then" output terminal
-                      on the If/Then is attached to the swap object's sequence in pin.
-         
+                      object is allowed to occur after executing the Sample and Hold to pass the
+                      most recent array to the swap User Object.  
+                      
                       The "else" terminal is attached to a gate object so that if the comparison
                       fails, i.e. the elements are in order, then the unchanged array is feed back
                       to the beginning of the feedback loop.  This very important. Note that if the
                       elements are in order the swap object is not allowed to execute.  In that case
-                      the unchanged array must be sent back to the Junction object.  There are three 
+                      the unchanged array must be sent back to the Junction object.  There are three
                       asynchronous data input pins on the Junction object, one for the initial un-
                       sorted array, one for the array after its elements have been swapped, and one
                       for the array if the elements are in order.
@@ -441,10 +883,6 @@
         )
        )
        (views
-        (description 2 9
-         This notepad is displayed as a Show on Execute
-         panel to present the information to the reader.
-        )
         (icon
          (origin 250 435)
          (extent 78 25)
@@ -459,6 +897,15 @@
       )
       (component 1 "Confirm"
        (name "DONE")
+       (description 7 8
+        This tiny "thread" begins running when the 
+        enclosing UserObject is executed.  When the user
+        acknowledges the OK/DONE button, there is nothing
+        left to execute, so the thread ends.  Since there
+        are not other threads running, the User Object
+        is completed and will exit, removing the Show on
+        Execute pop-up display.
+       )
        (interface
         (sequence in)
         (sequence out)
@@ -471,15 +918,6 @@
        (implementation
        )
        (views
-        (description 7 9
-         This tiny "thread" begins running when the 
-         enclosing UserObject is executed.  When the user
-         acknowledges the OK/DONE button, there is nothing
-         left to execute, so the thread ends.  Since there
-         are not other threads running, the User Object
-         is completed and will exit, removing the Show on
-         Execute pop-up display.
-        )
         (icon
          (origin 261 502)
          (extent 58 37)
@@ -540,11 +978,11 @@
      (extent 110 25)
     )
     (panel
-     (origin 371 592)
-     (extent 319 77)
+     (origin 15 119)
+     (extent 291 82)
      (widget 1 icon
       (title off)
-      (origin 473 605)
+      (origin 93 143)
       (extent 114 39)
       (format button)
      )
@@ -575,443 +1013,67 @@
     (active panel)
    )
   )
-  (component 11 "Context"
-   (name "Swap(x,y)")
+  (component 14 "Note"
+   (name "Please Note !!!")
    (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "ArrayIn")
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "Xindex")
-     (optional yes)
-    )
-    (input 3
-     (type data)
-     (name "Yindex")
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "SwappedArray")
-     (lock constraints)
-     (optional yes)
-    )
    )
    (implementation
-    (trigMode deg)
-    (locked no)
-    (component 0 "ToArray"
-     (interface
-      (sequence in)
-      (sequence out)
-      (input 1
-       (type data)
-       (name "Array")
-       (tag "Array")
-       (lock constraints)
-      )
-      (input 2
-       (type data)
-       (name "Datum")
-       (tag "Datum")
-       (requires
-        (shape "Scalar")
-       )
-       (lock constraints)
-      )
-      (input 3
-       (type data)
-       (name "Index 1")
-       (tag "Index 1")
-       (requires
-        (datatype Int32)
-        (shape "Scalar")
-       )
-       (lock constraints)
-      )
-      (input 4
-       (type trigger)
-       (name "XEQ")
-       (lock name constraints)
-      )
-      (output 1
-       (type data)
-       (name "Array")
-       (tag "Array")
-       (lock constraints)
-      )
-     )
-     (implementation
-      (component numDims 1)
-     )
-     (views
-      (icon
-       (origin 655 368)
-       (extent 110 64)
-       (iconImage build.icon)
-      )
-      (detail
-      )
-      (terminals on)
-      (active icon)
-     )
-    )
-    (component 1 "Formula"
-     (interface
-      (sequence in)
-      (sequence out)
-      (input 1
-       (type data)
-       (name "A")
-       (optional yes)
-      )
-      (input 2
-       (type data)
-       (name "B")
-       (optional yes)
-      )
-      (output 1
-       (type data)
-       (name "Result")
-       (lock name constraints)
-      )
-     )
-     (implementation
-      (component isLocked no)
-      (component expr 1 "A[B]")
-     )
-     (views
-      (icon
-       (origin 341 358)
-       (extent 78 64)
-       (iconImage formula.icon)
-      )
-      (detail
-       (origin 308 166)
-       (extent 74 108)
-      )
-      (terminals on)
-      (active icon)
-     )
-    )
-    (component 2 "Formula"
-     (interface
-      (sequence in)
-      (sequence out)
-      (input 1
-       (type data)
-       (name "A")
-       (optional yes)
-      )
-      (input 2
-       (type data)
-       (name "B")
-       (optional yes)
-      )
-      (output 1
-       (type data)
-       (name "Result")
-       (lock name constraints)
-      )
-     )
-     (implementation
-      (component isLocked no)
-      (component expr 1 "A[B]")
-     )
-     (views
-      (icon
-       (origin 341 178)
-       (extent 78 64)
-       (iconImage formula.icon)
-      )
-      (detail
-       (origin 308 166)
-       (extent 74 108)
-      )
-      (terminals on)
-      (active icon)
-     )
-    )
-    (component 3 "ToArray"
-     (interface
-      (sequence in)
-      (sequence out)
-      (input 1
-       (type data)
-       (name "Array")
-       (tag "Array")
-       (lock constraints)
-      )
-      (input 2
-       (type data)
-       (name "Datum")
-       (tag "Datum")
-       (requires
-        (shape "Scalar")
-       )
-       (lock constraints)
-      )
-      (input 3
-       (type data)
-       (name "Index 1")
-       (tag "Index 1")
-       (requires
-        (datatype Int32)
-        (shape "Scalar")
-       )
-       (lock constraints)
-      )
-      (input 4
-       (type trigger)
-       (name "XEQ")
-       (lock name constraints)
-      )
-      (output 1
-       (type data)
-       (name "Array")
-       (tag "Array")
-       (lock constraints)
-      )
-     )
-     (implementation
-      (component numDims 1)
-     )
-     (views
-      (icon
-       (origin 495 148)
-       (extent 110 64)
-       (iconImage build.icon)
-      )
-      (detail
-      )
-      (terminals on)
-      (active icon)
-     )
-    )
-    (configuration
-     (connect D3:1 D0:1)
-     (connect D1:1 D0:2)
-     (connect I2:1 D0:3)
-     (connect D3:0 D0:4)
-     (connect I1:1 D1:1)
-     (connect I3:1 D1:2)
-     (connect I1:1 D2:1)
-     (connect I2:1 D2:2)
-     (connect I1:1 D3:1)
-     (connect D2:1 D3:2)
-     (connect I3:1 D3:3)
-     (connect D2:0 D3:4)
-     (connect D0:1 O1:1)
+    (component text 5 5
+         This example is to demostrate a 
+       feedback technique.  This is NOT an
+        optimized sort routine. To see an
+        optimized sorting example, please
+     reference: examples/concepts/qsort.ex
     )
    )
    (views
-    (description 9 5
-     This model inside the User Object is explained in
-     the /examples/concepts directory, It is used to
-     swap any two elements of an array. The array can
-     be any of the Vee data types. The inputs are the
-     array, two of whose elements are to be swapped. 
-     The other two inputs are the indices of the two 
-     elements. The indices should be attached in the 
-     correct order as indicated by the terminal names.
-     
-    )
     (icon
-     (origin 630 298)
-     (extent 100 45)
+     (extent 145 0)
+     (iconImage "notepad.icon")
     )
     (detail
-     (origin 175 117)
-     (extent 641 387)
-     (configuration
-      (connect D3:1 D0:1
-       (Point 607 180)
-       (Point 620 180)
-       (Point 620 380)
-       (Point 652 380)
-      )
-      (connect D1:1 D0:2
-       (Point 421 390)
-       (Point 652 390)
-      )
-      (connect I2:1 D0:3
-       (Point 177 320)
-       (Point 200 320)
-       (Point 200 440)
-       (Point 440 440)
-       (Point 440 400)
-       (Point 652 400)
-      )
-      (connect D3:0 D0:4
-       (Point 550 214)
-       (Point 550 410)
-       (Point 652 410)
-      )
-      (connect I1:1 D1:1
-       (Point 177 190)
-       (Point 310 190)
-       (Point 310 370)
-       (Point 338 370)
-      )
-      (connect I3:1 D1:2
-       (Point 177 450)
-       (Point 190 450)
-       (Point 190 410)
-       (Point 338 410)
-      )
-      (connect I1:1 D2:1
-       (Point 177 190)
-       (Point 338 190)
-      )
-      (connect I2:1 D2:2
-       (Point 177 320)
-       (Point 190 320)
-       (Point 190 230)
-       (Point 338 230)
-      )
-      (connect I1:1 D3:1
-       (Point 177 190)
-       (Point 310 190)
-       (Point 310 160)
-       (Point 492 160)
-      )
-      (connect D2:1 D3:2
-       (Point 421 210)
-       (Point 440 210)
-       (Point 440 170)
-       (Point 492 170)
-      )
-      (connect I3:1 D3:3
-       (Point 177 450)
-       (Point 190 450)
-       (Point 190 410)
-       (Point 320 410)
-       (Point 320 340)
-       (Point 460 340)
-       (Point 460 180)
-       (Point 492 180)
-      )
-      (connect D2:0 D3:4
-       (Point 380 244)
-       (Point 380 260)
-       (Point 450 260)
-       (Point 450 190)
-       (Point 492 190)
-      )
-      (connect D0:1 O1:1
-       (Point 767 400)
-       (Point 780 400)
-       (Point 780 320)
-       (Point 813 320)
-      )
-     )
+     (origin 325 118)
+     (extent 351 105)
+     (editing enabled)
     )
-    (terminals on)
-    (active icon)
+    (active detail)
    )
   )
-  (component 12 "IfThenElse"
-   (name "A[B+1]<A[B]")
+  (component 15 "Note"
+   (name "Warranty Disclaimer")
    (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "A")
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "B")
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Then")
-     (lock name constraints)
-    )
-    (output 2
-     (type data)
-     (name "Else")
-     (lock name constraints)
-    )
    )
    (implementation
-    (component isLocked no)
-    (component expr "A[B+1]<A[B]")
+    (component text 5 5
+     This example is provided as an
+     illustration "as is", and 
+     Hewlett-PackardCompany makes no
+     warranty of any kind with regard
+      to this example.
+    )
    )
    (views
     (icon
-     (origin 454 228)
-     (extent 112 25)
+     (extent 181 0)
     )
     (detail
-     (origin 324 198)
-     (extent 163 104)
+     (origin 686 118)
+     (extent 309 105)
+     (editing disabled)
     )
-    (terminals on)
-    (active icon)
+    (active detail)
    )
   )
-  (component 13 "Junction"
-   (name "JCT")
+  (component 16 "Start"
    (interface
-    (input 1
-     (type data)
-     (name "A")
-     (lock name constraints)
-    )
-    (input 2
-     (type data)
-     (name "B")
-     (lock name constraints)
-    )
-    (input 3
-     (type data)
-     (name "C")
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Data")
-     (lock name constraints)
-    )
-   )
-   (implementation
-   )
-   (views
-    (icon
-     (origin 227 213)
-     (extent 46 34)
-    )
-    (detail
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 14 "RepeatUntilBreak"
-   (interface
-    (sequence in)
     (sequence out)
-    (output 1
-     (type data)
-     (name "Continuous")
-     (lock name constraints)
-    )
    )
    (implementation
    )
    (views
     (icon
-     (origin 45 348)
-     (extent 110 64)
-     (iconImage loop.icon)
+     (origin 67 232)
+     (extent 67 37)
     )
     (detail
     )
@@ -1022,147 +1084,153 @@
   (configuration
    (connect D1:1 D0:0)
    (connect D2:1 D1:1)
-   (connect D12:2 D2:1)
-   (connect D6:0 D2:2)
-   (connect D11:1 D3:1)
-   (connect D12:2 D4:0)
-   (connect D13:1 D4:1)
-   (connect D6:1 D5:1)
-   (connect D14:1 D6:0)
-   (connect D7:0 D8:0)
-   (connect D12:1 D11:0)
-   (connect D13:1 D11:1)
-   (connect D6:1 D11:2)
-   (connect D5:1 D11:3)
-   (connect D13:1 D12:1)
-   (connect D6:1 D12:2)
-   (connect D11:1 D13:1)
-   (connect D8:1 D13:2)
-   (connect D4:1 D13:3)
-   (connect D8:0 D14:0)
+   (connect D7:2 D2:1)
+   (connect D5:0 D2:2)
+   (connect D7:2 D3:0)
+   (connect D8:1 D3:1)
+   (connect D5:1 D4:1)
+   (connect D9:1 D5:0)
+   (connect D16:0 D6:0)
+   (connect D8:1 D7:1)
+   (connect D5:1 D7:2)
+   (connect D10:1 D8:1)
+   (connect D6:1 D8:2)
+   (connect D3:1 D8:3)
+   (connect D6:0 D9:0)
+   (connect D12:1 D10:1)
+   (connect D5:1 D10:2)
+   (connect D4:1 D10:3)
+   (connect D10:1 D11:1)
+   (connect D8:1 D12:1)
+   (connect D7:1 D12:2)
   )
  )
  (views
   (detail
    (origin 0 67)
-   (extent 984 651)
+   (extent 1004 664)
    (configuration
     (connect D1:1 D0:0
-     (Point 791 500)
-     (Point 850 500)
-     (Point 850 545)
+     (Point 791 630)
+     (Point 850 630)
+     (Point 850 675)
     )
     (connect D2:1 D1:1
-     (Point 691 510)
-     (Point 708 510)
+     (Point 691 640)
+     (Point 708 640)
     )
-    (connect D12:2 D2:1
-     (Point 568 250)
-     (Point 580 250)
-     (Point 580 500)
-     (Point 608 500)
+    (connect D7:2 D2:1
+     (Point 568 380)
+     (Point 580 380)
+     (Point 580 630)
+     (Point 608 630)
     )
-    (connect D6:0 D2:2
-     (Point 280 469)
-     (Point 280 520)
-     (Point 608 520)
+    (connect D5:0 D2:2
+     (Point 280 599)
+     (Point 280 650)
+     (Point 608 650)
     )
-    (connect D11:1 D3:1
-     (Point 732 320)
-     (Point 771 320)
+    (connect D7:2 D3:0
+     (Point 568 380)
+     (Point 580 380)
+     (Point 580 400)
+     (Point 330 400)
+     (Point 330 415)
     )
-    (connect D12:2 D4:0
-     (Point 568 250)
-     (Point 580 250)
-     (Point 580 270)
-     (Point 330 270)
-     (Point 330 285)
+    (connect D8:1 D3:1
+     (Point 275 360)
+     (Point 290 360)
+     (Point 290 430)
+     (Point 304 430)
     )
-    (connect D13:1 D4:1
-     (Point 275 230)
-     (Point 290 230)
-     (Point 290 300)
-     (Point 304 300)
+    (connect D5:1 D4:1
+     (Point 367 580)
+     (Point 390 580)
+     (Point 390 480)
+     (Point 424 480)
     )
-    (connect D6:1 D5:1
-     (Point 367 450)
-     (Point 390 450)
-     (Point 390 350)
-     (Point 424 350)
+    (connect D9:1 D5:0
+     (Point 157 510)
+     (Point 280 510)
+     (Point 280 530)
     )
-    (connect D14:1 D6:0
-     (Point 157 380)
-     (Point 280 380)
-     (Point 280 400)
+    (connect D16:0 D6:0
+     (Point 100 271)
+     (Point 100 298)
     )
-    (connect D7:0 D8:0
-     (Point 100 131)
-     (Point 100 168)
+    (connect D8:1 D7:1
+     (Point 275 360)
+     (Point 451 360)
     )
-    (connect D12:1 D11:0
-     (Point 568 230)
-     (Point 680 230)
-     (Point 680 295)
+    (connect D5:1 D7:2
+     (Point 367 580)
+     (Point 390 580)
+     (Point 390 480)
+     (Point 410 480)
+     (Point 410 380)
+     (Point 451 380)
     )
-    (connect D13:1 D11:1
-     (Point 275 230)
-     (Point 430 230)
-     (Point 430 210)
-     (Point 590 210)
-     (Point 590 310)
-     (Point 627 310)
+    (connect D10:1 D8:1
+     (Point 722 450)
+     (Point 760 450)
+     (Point 760 320)
+     (Point 210 320)
+     (Point 210 350)
+     (Point 224 350)
     )
-    (connect D6:1 D11:2
-     (Point 367 450)
-     (Point 390 450)
-     (Point 390 350)
-     (Point 410 350)
-     (Point 410 320)
-     (Point 627 320)
+    (connect D6:1 D8:2
+     (Point 177 390)
+     (Point 200 390)
+     (Point 200 360)
+     (Point 224 360)
     )
-    (connect D5:1 D11:3
-     (Point 475 350)
-     (Point 490 350)
-     (Point 490 330)
-     (Point 627 330)
+    (connect D3:1 D8:3
+     (Point 355 430)
+     (Point 370 430)
+     (Point 370 460)
+     (Point 210 460)
+     (Point 210 370)
+     (Point 224 370)
     )
-    (connect D13:1 D12:1
-     (Point 275 230)
-     (Point 451 230)
+    (connect D6:0 D9:0
+     (Point 100 451)
+     (Point 100 475)
     )
-    (connect D6:1 D12:2
-     (Point 367 450)
-     (Point 390 450)
-     (Point 390 350)
-     (Point 410 350)
-     (Point 410 250)
-     (Point 451 250)
+    (connect D12:1 D10:1
+     (Point 726 350)
+     (Point 740 350)
+     (Point 740 380)
+     (Point 600 380)
+     (Point 600 440)
+     (Point 617 440)
     )
-    (connect D11:1 D13:1
-     (Point 732 320)
-     (Point 750 320)
-     (Point 750 190)
-     (Point 210 190)
-     (Point 210 220)
-     (Point 224 220)
+    (connect D5:1 D10:2
+     (Point 367 580)
+     (Point 390 580)
+     (Point 390 480)
+     (Point 410 480)
+     (Point 410 450)
+     (Point 617 450)
     )
-    (connect D8:1 D13:2
-     (Point 177 260)
-     (Point 200 260)
-     (Point 200 230)
-     (Point 224 230)
+    (connect D4:1 D10:3
+     (Point 475 480)
+     (Point 490 480)
+     (Point 490 460)
+     (Point 617 460)
     )
-    (connect D4:1 D13:3
-     (Point 355 300)
-     (Point 370 300)
-     (Point 370 330)
-     (Point 210 330)
-     (Point 210 240)
-     (Point 224 240)
+    (connect D10:1 D11:1
+     (Point 722 450)
+     (Point 791 450)
     )
-    (connect D8:0 D14:0
-     (Point 100 321)
-     (Point 100 345)
+    (connect D8:1 D12:1
+     (Point 275 360)
+     (Point 430 360)
+     (Point 430 340)
+     (Point 594 340)
+    )
+    (connect D7:1 D12:2
+     (Point 568 360)
+     (Point 594 360)
     )
    )
   )
