@@ -1,6 +1,6 @@
-#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
+#! /usr/lib/veetest/veetest -r
 (revision "A.00.00")
-(date "Thu 11/Apr/1991")
+(date "Thu 02/May/1991")
 (component 0 "Context"
  (name "Set Mappings Example")
  (interface
@@ -8,24 +8,7 @@
  (implementation
   (trigMode deg)
   (locked no)
-  (component 0 "Start"
-   (interface
-    (sequence out)
-   )
-   (implementation
-   )
-   (views
-    (icon
-     (origin 97 92)
-     (extent 67 37)
-    )
-    (detail
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 1 "FromSpectrum"
+  (component 0 "FromSpectrum"
    (interface
     (sequence in)
     (sequence out)
@@ -62,7 +45,7 @@
    )
    (views
     (icon
-     (origin 53 388)
+     (origin 83 408)
      (extent 154 64)
      (iconImage unbuild.icon)
     )
@@ -74,7 +57,7 @@
     (active icon)
    )
   )
-  (component 2 "FromPComplex"
+  (component 1 "FromPComplex"
    (name "UnBuild PComplex")
    (interface
     (sequence in)
@@ -102,7 +85,7 @@
    )
    (views
     (icon
-     (origin 53 298)
+     (origin 83 318)
      (extent 154 64)
      (iconImage unbuild.icon)
     )
@@ -114,7 +97,7 @@
     (active icon)
    )
   )
-  (component 3 "Formula"
+  (component 2 "Formula"
    (name "maxX(x)")
    (interface
     (sequence in)
@@ -136,7 +119,7 @@
    )
    (views
     (icon
-     (origin 271 298)
+     (origin 301 318)
      (extent 78 25)
     )
     (detail
@@ -145,7 +128,7 @@
     (active icon)
    )
   )
-  (component 4 "Formula"
+  (component 3 "Formula"
    (name "max(x)")
    (interface
     (sequence in)
@@ -167,7 +150,7 @@
    )
    (views
     (icon
-     (origin 411 408)
+     (origin 441 428)
      (extent 78 25)
     )
     (detail
@@ -176,7 +159,7 @@
     (active icon)
    )
   )
-  (component 5 "ToFunction"
+  (component 4 "ToFunction"
    (interface
     (sequence in)
     (sequence out)
@@ -227,7 +210,7 @@
    )
    (views
     (icon
-     (origin 261 388)
+     (origin 291 408)
      (extent 118 64)
      (iconImage build.icon)
     )
@@ -239,7 +222,132 @@
     (active icon)
    )
   )
-  (component 6 "Context"
+  (component 5 "YPlot"
+   (name "Magnitude Spectrum")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Trace1")
+     (lock constraints)
+    )
+    (input 2
+     (type control)
+     (name "Auto Scale")
+     (lock name constraints)
+     (optional yes)
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+    (component tracePin 1)
+    (component graphMode freqmag)
+   )
+   (views
+    (icon
+     (iconImage display.icon)
+    )
+    (detail
+     (origin 610 132)
+     (extent 360 296)
+     (displayMode scrollGraph)
+     (graphType cartesian)
+     (gridType grid)
+     (scale 0
+      (name "Mag")
+      (domainName "Freq")
+      (color 0x909090)
+      (show 1)
+      (range 0 250000 4 linear)
+     )
+     (domain 0 7000 4 linear)
+     (trace 0 onScale 0
+      (name "Trace1")
+      (color 0xffdd00)
+      (lineType 1)
+      (pointType 0)
+     )
+    )
+    (active detail)
+   )
+  )
+  (component 6 "TextDisplay"
+   (name "Max Freq Component, Hz")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 208 0)
+    )
+    (detail
+     (origin 619 473)
+     (extent 282 35)
+    )
+    (active detail)
+   )
+  )
+  (component 7 "TextDisplay"
+   (name "Max Magnitude")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 127 0)
+    )
+    (detail
+     (origin 619 553)
+     (extent 282 35)
+    )
+    (active detail)
+   )
+  )
+  (component 8 "Note"
+   (name "Warranty Disclaimer")
+   (interface
+   )
+   (implementation
+    (component text 4 5
+     This example is provided as an
+     illustration "as is", and Hewlett-Packard
+     Company makes no warranty of any kind
+     with regard to this example.
+    )
+   )
+   (views
+    (icon
+     (extent 181 0)
+    )
+    (detail
+     (origin 482 639)
+     (extent 397 82)
+     (editing disabled)
+    )
+    (active detail)
+   )
+  )
+  (component 9 "Context"
    (name "Press For")
    (interface
     (sequence in)
@@ -279,7 +387,7 @@
      )
      (views
       (icon
-       (origin 233 341)
+       (origin 203 491)
        (extent 114 39)
        (format button)
       )
@@ -318,7 +426,7 @@
      )
      (views
       (icon
-       (origin 397 348)
+       (origin 367 498)
        (extent 46 25)
       )
       (detail
@@ -343,7 +451,7 @@
      )
      (views
       (icon
-       (origin 155 268)
+       (origin 125 418)
        (extent 110 64)
        (iconImage loop.icon)
       )
@@ -372,7 +480,7 @@
                   the Unbuild Spectrum, UnBuild PComplex, and Set Mappings objects.  All these 
                   objects are under the main menu choice, Data. 
          
-         USER INPUT REQUIRED: None
+         USER INPUT REQUIRED: Press "Run" to start execution.
          
          EXPLANATION: This example builds a complex, random waveform by continuosly adding sine
                       waves with random amplitudes and phase shifts and frequencies from 5 to 5000
@@ -458,16 +566,16 @@
        (origin 55 78)
        (extent 877 570)
        (panel
-        (origin 64 164)
+        (origin 14 314)
         (extent 873 532)
         (widget 1 icon
          (title off)
-         (origin 463 649)
+         (origin 413 799)
          (extent 58 37)
         )
         (widget 0 detail
          (title off)
-         (origin 78 177)
+         (origin 28 327)
          (extent 845 461)
          (editing disabled)
         )
@@ -476,7 +584,7 @@
      )
      (views
       (icon
-       (origin 372 418)
+       (origin 342 568)
        (extent 217 25)
       )
       (detail
@@ -501,39 +609,39 @@
      (extent 110 25)
     )
     (panel
-     (origin 51 622)
+     (origin 81 642)
      (extent 319 77)
      (widget 0 icon
       (title off)
-      (origin 153 635)
+      (origin 183 655)
       (extent 114 39)
       (format button)
      )
     )
     (detail
-     (origin 34 115)
+     (origin 4 265)
      (extent 912 591)
      (configuration
       (connect D2:1 D0:0
-       (Point 267 300)
-       (Point 290 300)
-       (Point 290 338)
+       (Point 237 450)
+       (Point 260 450)
+       (Point 260 488)
       )
       (connect D3:0 D0:1
-       (Point 480 445)
-       (Point 480 460)
-       (Point 210 460)
-       (Point 210 360)
-       (Point 230 360)
+       (Point 450 595)
+       (Point 450 610)
+       (Point 180 610)
+       (Point 180 510)
+       (Point 200 510)
       )
       (connect D0:1 D1:1
-       (Point 349 360)
-       (Point 394 360)
+       (Point 319 510)
+       (Point 364 510)
       )
       (connect D1:1 D3:0
-       (Point 445 350)
-       (Point 480 350)
-       (Point 480 415)
+       (Point 415 500)
+       (Point 450 500)
+       (Point 450 565)
       )
      )
     )
@@ -541,7 +649,7 @@
     (active panel)
    )
   )
-  (component 7 "Context"
+  (component 10 "Context"
    (name "Create Random Waveform")
    (interface
     (sequence in)
@@ -698,9 +806,9 @@
      (implementation
       (component function Cosine)
       (component frequency 5005)
-      (component amplitude 50.40740754819178)
+      (component amplitude 27.55331204943281)
       (component dcOffset 0)
-      (component phaseShift 99.29096225024053)
+      (component phaseShift 181.6478538413326)
       (component numPoints 256)
       (component interval 0.02)
       (component degRad Deg)
@@ -788,7 +896,7 @@
    )
    (views
     (icon
-     (origin 26 168)
+     (origin 56 128)
      (extent 208 25)
     )
     (detail
@@ -860,7 +968,26 @@
     (active icon)
    )
   )
-  (component 8 "Formula"
+  (component 11 "ExitProcess"
+   (interface
+    (sequence in)
+   )
+   (implementation
+    (comp code 0)
+   )
+   (views
+    (icon
+     (origin 137 188)
+     (extent 46 25)
+    )
+    (detail
+     (origin 340 513)
+     (extent 120 34)
+    )
+    (active icon)
+   )
+  )
+  (component 12 "Formula"
    (name "fft(x)")
    (interface
     (sequence in)
@@ -882,7 +1009,7 @@
    )
    (views
     (icon
-     (origin 271 168)
+     (origin 331 128)
      (extent 78 25)
     )
     (detail
@@ -891,224 +1018,103 @@
     (active icon)
    )
   )
-  (component 9 "YPlot"
-   (name "Magnitude Spectrum")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Trace1")
-     (lock constraints)
-    )
-    (input 2
-     (type control)
-     (name "Auto Scale")
-     (lock name constraints)
-     (optional yes)
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-    (component tracePin 1)
-    (component graphMode freqmag)
-   )
-   (views
-    (icon
-     (iconImage display.icon)
-    )
-    (detail
-     (origin 580 112)
-     (extent 360 296)
-     (displayMode scrollGraph)
-     (graphType cartesian)
-     (gridType grid)
-     (scale 0
-      (name "Mag")
-      (domainName "Freq")
-      (color 0x909090)
-      (show 1)
-      (range 0 250000 4 linear)
-     )
-     (domain 0 7000 4 linear)
-     (trace 0 onScale 0
-      (name "Trace1")
-      (color 0xffdd00)
-      (lineType 1)
-      (pointType 0)
-     )
-    )
-    (active detail)
-   )
-  )
-  (component 10 "TextDisplay"
-   (name "Max Freq Component, Hz")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-     (extent 208 0)
-    )
-    (detail
-     (origin 589 453)
-     (extent 282 35)
-    )
-    (active detail)
-   )
-  )
-  (component 11 "TextDisplay"
-   (name "Max Magnitude")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-     (extent 127 0)
-    )
-    (detail
-     (origin 589 533)
-     (extent 282 35)
-    )
-    (active detail)
-   )
-  )
-  (component 12 "Note"
-   (name "Warranty Disclaimer")
-   (interface
-   )
-   (implementation
-    (component text 4 5
-     This example is provided as an
-     illustration "as is", and Hewlett-Packard
-     Company makes no warranty of any kind
-     with regard to this example.
-    )
-   )
-   (views
-    (icon
-     (extent 181 0)
-    )
-    (detail
-     (origin 452 619)
-     (extent 397 82)
-     (editing disabled)
-    )
-    (active detail)
-   )
-  )
   (configuration
-   (connect D8:1 D1:1)
-   (connect D1:1 D2:1)
-   (connect D5:1 D3:1)
-   (connect D5:1 D4:1)
-   (connect D2:1 D5:1)
-   (connect D1:2 D5:2)
-   (connect D1:3 D5:3)
-   (connect D0:0 D7:0)
-   (connect D7:1 D8:1)
-   (connect D8:1 D9:1)
-   (connect D8:0 D9:2)
-   (connect D3:1 D10:1)
-   (connect D4:1 D11:1)
+   (connect D12:1 D0:1)
+   (connect D0:1 D1:1)
+   (connect D4:1 D2:1)
+   (connect D4:1 D3:1)
+   (connect D1:1 D4:1)
+   (connect D0:2 D4:2)
+   (connect D0:3 D4:3)
+   (connect D12:1 D5:1)
+   (connect D12:0 D5:2)
+   (connect D2:1 D6:1)
+   (connect D3:1 D7:1)
+   (connect D10:0 D11:0)
+   (connect D10:1 D12:1)
   )
  )
  (views
   (detail
    (origin 0 67)
-   (extent 980 651)
+   (extent 1043 828)
    (configuration
-    (connect D8:1 D1:1
-     (Point 351 180)
-     (Point 370 180)
-     (Point 370 220)
-     (Point 20 220)
-     (Point 20 420)
-     (Point 50 420)
+    (connect D12:1 D0:1
+     (Point 411 140)
+     (Point 430 140)
+     (Point 430 200)
+     (Point 420 200)
+     (Point 420 230)
+     (Point 50 230)
+     (Point 50 440)
+     (Point 80 440)
     )
-    (connect D1:1 D2:1
-     (Point 209 400)
-     (Point 220 400)
-     (Point 220 380)
-     (Point 30 380)
-     (Point 30 330)
-     (Point 50 330)
+    (connect D0:1 D1:1
+     (Point 239 420)
+     (Point 250 420)
+     (Point 250 400)
+     (Point 60 400)
+     (Point 60 350)
+     (Point 80 350)
     )
-    (connect D5:1 D3:1
-     (Point 381 420)
-     (Point 400 420)
-     (Point 400 370)
-     (Point 250 370)
-     (Point 250 310)
-     (Point 268 310)
+    (connect D4:1 D2:1
+     (Point 411 440)
+     (Point 430 440)
+     (Point 430 390)
+     (Point 280 390)
+     (Point 280 330)
+     (Point 298 330)
     )
-    (connect D5:1 D4:1
-     (Point 381 420)
-     (Point 408 420)
+    (connect D4:1 D3:1
+     (Point 411 440)
+     (Point 438 440)
     )
-    (connect D2:1 D5:1
-     (Point 209 310)
-     (Point 230 310)
-     (Point 230 400)
-     (Point 258 400)
+    (connect D1:1 D4:1
+     (Point 239 330)
+     (Point 260 330)
+     (Point 260 420)
+     (Point 288 420)
     )
-    (connect D1:2 D5:2
-     (Point 209 420)
-     (Point 258 420)
+    (connect D0:2 D4:2
+     (Point 239 440)
+     (Point 288 440)
     )
-    (connect D1:3 D5:3
-     (Point 209 440)
-     (Point 258 440)
+    (connect D0:3 D4:3
+     (Point 239 460)
+     (Point 288 460)
     )
-    (connect D0:0 D7:0
-     (Point 130 131)
-     (Point 130 165)
+    (connect D12:1 D5:1
+     (Point 411 140)
+     (Point 430 140)
+     (Point 430 200)
+     (Point 607 200)
     )
-    (connect D7:1 D8:1
-     (Point 236 180)
-     (Point 268 180)
+    (connect D12:0 D5:2
+     (Point 370 155)
+     (Point 370 210)
+     (Point 560 210)
+     (Point 560 360)
+     (Point 607 360)
     )
-    (connect D8:1 D9:1
-     (Point 351 180)
-     (Point 577 180)
+    (connect D2:1 D6:1
+     (Point 381 330)
+     (Point 550 330)
+     (Point 550 490)
+     (Point 616 490)
     )
-    (connect D8:0 D9:2
-     (Point 310 195)
-     (Point 310 210)
-     (Point 530 210)
-     (Point 530 340)
-     (Point 577 340)
+    (connect D3:1 D7:1
+     (Point 521 440)
+     (Point 540 440)
+     (Point 540 570)
+     (Point 616 570)
     )
-    (connect D3:1 D10:1
-     (Point 351 310)
-     (Point 520 310)
-     (Point 520 470)
-     (Point 586 470)
+    (connect D10:0 D11:0
+     (Point 160 155)
+     (Point 160 185)
     )
-    (connect D4:1 D11:1
-     (Point 491 420)
-     (Point 510 420)
-     (Point 510 550)
-     (Point 586 550)
+    (connect D10:1 D12:1
+     (Point 266 140)
+     (Point 328 140)
     )
    )
   )
